@@ -38,7 +38,6 @@ TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR TH
 
 # External library imports
 import sys
-import os
 import time
 import warnings
 import pandas as pd
@@ -51,6 +50,7 @@ from . import tables
 from . import network_selection
 from . import layouts
 from . import session
+from . import sandbox
 
 # Internal module convenience imports
 from .py4cytoscape_utils import *
@@ -58,6 +58,7 @@ from .py4cytoscape_logger import cy_log
 from .py4cytoscape_tuning import MODEL_PROPAGATION_SECS, CATCHUP_NETWORK_SECS
 from .exceptions import CyError
 from .py4cytoscape_notebook import running_remote
+from .py4cytoscape_sandbox import get_abs_sandbox_path
 
 def __init__(self):
     pass
@@ -70,7 +71,7 @@ def set_current_network(network=None, base_url=DEFAULT_BASE_URL):
     Args:
         network (SUID or str or None): Network name or SUID of the network that you want set as current
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -106,7 +107,7 @@ def rename_network(title, network=None, base_url=DEFAULT_BASE_URL):
         title (str): New name for the network
         network (SUID or str or None): name or SUID of the network that you want to rename; default is "current" network
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -137,7 +138,7 @@ def get_network_count(base_url=DEFAULT_BASE_URL):
 
     Args:
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -163,7 +164,7 @@ def get_network_name(suid=None, base_url=DEFAULT_BASE_URL):
         suid (SUID or str or None): SUID of the network; default is current network. If a name is
             provided, then it is validated and returned.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -216,7 +217,7 @@ def get_network_suid(title=None, base_url=DEFAULT_BASE_URL):
         suid (SUID or str or None): Name of the network; default is "current" network. If an SUID is
             provided, then it is validated and returned.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -273,7 +274,7 @@ def get_network_list(base_url=DEFAULT_BASE_URL):
 
     Args:
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -309,7 +310,7 @@ def export_network(filename=None, type='SIF', network=None, base_url=DEFAULT_BAS
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -326,7 +327,7 @@ def export_network(filename=None, type='SIF', network=None, base_url=DEFAULT_BAS
     cmd = 'network export'  # a good start
 
     # filename must be suppled
-    if filename is None: filename = get_network_name(network)
+    if filename is None: filename = get_abs_sandbox_path(get_network_name(network), force_cwd=True)
 
     # optional args
     if network is not None: cmd += ' network="SUID:' + str(get_network_suid(network, base_url=base_url)) + '"'
@@ -342,12 +343,12 @@ def export_network(filename=None, type='SIF', network=None, base_url=DEFAULT_BAS
 
     ext = '.' + type.lower()
     if re.search(ext + '$', filename) is None: filename += ext
-    if not running_remote():
-        filename = os.path.abspath(filename)
-        if os.path.exists(filename): narrate(
-            'This file already exists. A Cytoscape popup will be generated to confirm overwrite.')
 
-    return commands.commands_post(f'{cmd} OutputFile="{filename}"', base_url=base_url)
+    file_info = sandbox.sandbox_get_file_info(filename)
+    if len(file_info['modifiedTime']) and file_info['isFile']:
+        narrate('This file already exists. A Cytoscape popup will be generated to confirm overwrite.')
+
+    return commands.commands_post(f'{cmd} OutputFile="{get_abs_sandbox_path(filename)}"', base_url=base_url)
 
 
 @cy_log
@@ -358,7 +359,7 @@ def delete_network(network=None, base_url=DEFAULT_BASE_URL):
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -370,8 +371,11 @@ def delete_network(network=None, base_url=DEFAULT_BASE_URL):
 
     Examples:
         >>> delete_network() # delete the current network
+        ''
         >>> delete_network(22752) # delete network having SUID
+        ''
         >>> delete_network('galFiltered.sif') # delete network having name
+        ''
     """
     suid = get_network_suid(network)
     res = commands.cyrest_delete(f'networks/{suid}', base_url=base_url, require_json=False)
@@ -384,7 +388,7 @@ def delete_all_networks(base_url=DEFAULT_BASE_URL):
 
     Args:
          base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -415,7 +419,7 @@ def get_first_neighbors(node_names=None, as_nested_list=False, network=None, bas
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -477,7 +481,7 @@ def add_cy_nodes(node_names, skip_duplicate_names=True, network=None, base_url=D
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -510,7 +514,7 @@ def get_node_count(network=None, base_url=DEFAULT_BASE_URL):
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -542,7 +546,7 @@ def get_all_nodes(network=None, base_url=DEFAULT_BASE_URL):
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -581,7 +585,7 @@ def add_cy_edges(source_target_list, edge_type='interacts with', directed=False,
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -629,7 +633,7 @@ def get_edge_count(network=None, base_url=DEFAULT_BASE_URL):
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-             port or version to connect to the CyREST API. Default is http://localhost:1234
+             port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
              and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -663,7 +667,7 @@ def get_edge_info(edges, network=None, base_url=DEFAULT_BASE_URL):
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-             port or version to connect to the CyREST API. Default is http://localhost:1234
+             port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
              and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -710,7 +714,7 @@ def get_all_edges(network=None, base_url=DEFAULT_BASE_URL):
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -745,7 +749,7 @@ def clone_network(network=None, base_url=DEFAULT_BASE_URL):
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -782,7 +786,7 @@ def create_subnetwork(nodes=None, nodes_by_col='SUID', edges=None, edges_by_col=
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -807,8 +811,8 @@ def create_subnetwork(nodes=None, nodes_by_col='SUID', edges=None, edges_by_col=
     if isinstance(nodes, str) and nodes in ['all', 'selected', 'unselected']: nodes_by_col = None
     if isinstance(edges, str) and edges in ['all', 'selected', 'unselected']: edges_by_col = None
     json_sub = {'source': 'SUID:' + str(title), 'excludeEdges': exclude_edges,
-                'nodeList': commands.prep_post_query_lists(nodes, nodes_by_col),
-                'edgeList': commands.prep_post_query_lists(edges, edges_by_col)}
+                'nodeList': _prep_post_query_lists(nodes, nodes_by_col),
+                'edgeList': _prep_post_query_lists(edges, edges_by_col)}
     if not subnetwork_name is None: json_sub['networkName'] = subnetwork_name
 
     res = commands.cyrest_post('commands/network/create', body=json_sub, base_url=base_url)
@@ -840,7 +844,7 @@ def create_network_from_igraph(igraph, title='From igraph', collection='My Igrap
         title (str): network name
         collection (str): network collection name
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -909,7 +913,7 @@ def create_network_from_networkx(netx, title='From networkx', collection='My Net
         title (str): network name
         collection (str): network collection name
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -979,7 +983,7 @@ def create_network_from_data_frames(nodes=None, edges=None, title='From datafram
         title (str): network name
         collection (str): network collection name
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
         * :
         node_id_list (str): Name of column in ``nodes`` containing node id
@@ -1092,7 +1096,7 @@ def import_network_from_file(file=None, base_url=DEFAULT_BASE_URL):
         file (str): Name of file in any of the supported formats (e.g., SIF, GML, xGMML, etc).
             If None, a demo network file in SIF format is loaded.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -1109,10 +1113,8 @@ def import_network_from_file(file=None, base_url=DEFAULT_BASE_URL):
         {'networks': [131481], 'views': [131850]}
     """
     if file is None:
-        file = 'data/galFiltered.sif'
-    if not running_remote():
-        file = os.path.abspath(file)
-    res = commands.commands_post(f'network load file file="{file}"', base_url=base_url)
+        file = get_abs_sandbox_path('data/galFiltered.sif', force_cwd=True)
+    res = commands.commands_post(f'network load file file="{get_abs_sandbox_path(file)}"', base_url=base_url)
     # TODO: Fix R documentation to match what's really returned
     # TODO: Put double quotes around file
 
@@ -1145,7 +1147,7 @@ def create_igraph_from_network(network=None, base_url=DEFAULT_BASE_URL):
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -1216,7 +1218,7 @@ def create_networkx_from_network(network=None, base_url=DEFAULT_BASE_URL):
         network (SUID or str or None): Name or SUID of a network or view. Default is the
             "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -1277,3 +1279,16 @@ def create_networkx_from_network(network=None, base_url=DEFAULT_BASE_URL):
 # Dev Notes: Prefix internal functions with a '_'. Skip doc_strings for these
 # functions.
 # ------------------------------------------------------------------------------
+
+
+
+def _prep_post_query_lists(cmd_list=None, cmd_by_col=None):
+    if cmd_list is None:
+        cmd_list_ready = 'selected'
+    elif not cmd_by_col is None:
+        cmd_list_col = [cmd_by_col + ':' + cmd for cmd in cmd_list]
+        cmd_list_ready = ','.join(cmd_list_col)
+    else:
+        cmd_list_ready = cmd_list if isinstance(cmd_list, str) else ','.join(cmd_list)
+
+    return cmd_list_ready
\ No newline at end of file
